from ..broker import Broker


class DeviceQosStatBroker(Broker):
    controller = "device_qos_stats"

    def index(self, **kwargs):
        """Lists the available device qos stats. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of each device from which Qos was calculated or collected.
             :type DeviceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of each device from which Qos was calculated or collected.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceQosID: The internal NetMRI identifier for the Device Quality of Service.
             :type DeviceQosID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceQosID: The internal NetMRI identifier for the Device Quality of Service.
             :type DeviceQosID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the local interface of the Device Qos Statistics.
             :type InterfaceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the local interface of the Device Qos Statistics.
             :type InterfaceID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` today

             :param starttime: The data returned will represent the device qos stats with this date and time as lower boundary. If omitted, the result will indicate the most recently collected data.
             :type starttime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` tomorrow

             :param endtime: The data returned will represent the device qos stats with this date and time as upper boundary. If omitted, the result will indicate the most recently collected data.
             :type endtime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceQosID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceQosID. Valid values are DeviceQosID, DeviceID, InterfaceID, StartTime, EndTime, QosPolicyIndex, QosObjectsIndex, QosConfigIndex, QosObjectsType, QosCMName, QosCMDesc, QosCMInfo, QosIfType, QosPolicyDirection, QosIfIndex, QosCMPrePolicyPkt, QosCMDropPkt, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceQosStat. Valid values are DeviceQosID, DeviceID, InterfaceID, StartTime, EndTime, QosPolicyIndex, QosObjectsIndex, QosConfigIndex, QosObjectsType, QosCMName, QosCMDesc, QosCMInfo, QosIfType, QosPolicyDirection, QosIfIndex, QosCMPrePolicyPkt, QosCMDropPkt, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_qos_stats: An array of the DeviceQosStat objects that match the specified input criteria.
             :rtype device_qos_stats: Array of DeviceQosStat

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def show(self, **kwargs):
        """Shows the details for the specified device qos stat.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceQosID: The internal NetMRI identifier for the Device Quality of Service.
             :type DeviceQosID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_qos_stat: The device qos stat identified by the specified DeviceQosID.
             :rtype device_qos_stat: DeviceQosStat

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def search(self, **kwargs):
        """Lists the available device qos stats matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of each device from which Qos was calculated or collected.
             :type DeviceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of each device from which Qos was calculated or collected.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceQosID: The internal NetMRI identifier for the Device Quality of Service.
             :type DeviceQosID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceQosID: The internal NetMRI identifier for the Device Quality of Service.
             :type DeviceQosID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param EndTime: The date and time the record was last modified in NetMRI.
             :type EndTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EndTime: The date and time the record was last modified in NetMRI.
             :type EndTime: Array of DateTime

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the local interface of the Device Qos Statistics.
             :type InterfaceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the local interface of the Device Qos Statistics.
             :type InterfaceID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMDesc: The common description of Qos Statistics of each device.
             :type QosCMDesc: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMDesc: The common description of Qos Statistics of each device.
             :type QosCMDesc: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMDropPkt: The number of common drop packet defined in the Qos statistics of each device.
             :type QosCMDropPkt: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMDropPkt: The number of common drop packet defined in the Qos statistics of each device.
             :type QosCMDropPkt: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMInfo: The common information of Device Qos Statistics.
             :type QosCMInfo: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMInfo: The common information of Device Qos Statistics.
             :type QosCMInfo: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMName: The common name of Qos statistics of each device.
             :type QosCMName: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMName: The common name of Qos statistics of each device.
             :type QosCMName: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMPrePolicyPkt: The number of common policy packet defined in the Qos statistics of each device.
             :type QosCMPrePolicyPkt: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosCMPrePolicyPkt: The number of common policy packet defined in the Qos statistics of each device.
             :type QosCMPrePolicyPkt: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosConfigIndex: The config value of Qos statistics of each device.
             :type QosConfigIndex: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosConfigIndex: The config value of Qos statistics of each device.
             :type QosConfigIndex: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosIfIndex: The current value of the Device Qos Statistics.
             :type QosIfIndex: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosIfIndex: The current value of the Device Qos Statistics.
             :type QosIfIndex: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosIfType: The type of Device Qos Statistics.
             :type QosIfType: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosIfType: The type of Device Qos Statistics.
             :type QosIfType: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosObjectsIndex: The object index of Qos statistics of each device.
             :type QosObjectsIndex: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosObjectsIndex: The object index of Qos statistics of each device.
             :type QosObjectsIndex: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosObjectsType: The NetMRI-determined the object type of Device Qos Statistics.
             :type QosObjectsType: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosObjectsType: The NetMRI-determined the object type of Device Qos Statistics.
             :type QosObjectsType: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosPolicyDirection: Describes the direction of policy defined in the Qos.
             :type QosPolicyDirection: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosPolicyDirection: Describes the direction of policy defined in the Qos.
             :type QosPolicyDirection: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosPolicyIndex: The policy value of Quality of service in each device.
             :type QosPolicyIndex: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosPolicyIndex: The policy value of Quality of service in each device.
             :type QosPolicyIndex: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosSetCfgIpDSCPValue: Defines the configuration IP address of device statistics.
             :type QosSetCfgIpDSCPValue: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosSetCfgIpDSCPValue: Defines the configuration IP address of device statistics.
             :type QosSetCfgIpDSCPValue: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param QosSetCfgIpPrecedenceValue: The precedence value of configuration IP address.
             :type QosSetCfgIpPrecedenceValue: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param QosSetCfgIpPrecedenceValue: The precedence value of configuration IP address.
             :type QosSetCfgIpPrecedenceValue: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param StartTime: The date and time the record is initially created in the NetMRI.
             :type StartTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param StartTime: The date and time the record is initially created in the NetMRI.
             :type StartTime: Array of DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` today

             :param starttime: The data returned will represent the device qos stats with this date and time as lower boundary. If omitted, the result will indicate the most recently collected data.
             :type starttime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` tomorrow

             :param endtime: The data returned will represent the device qos stats with this date and time as upper boundary. If omitted, the result will indicate the most recently collected data.
             :type endtime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceQosID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceQosID. Valid values are DeviceQosID, DeviceID, InterfaceID, StartTime, EndTime, QosPolicyIndex, QosObjectsIndex, QosConfigIndex, QosObjectsType, QosCMName, QosCMDesc, QosCMInfo, QosIfType, QosPolicyDirection, QosIfIndex, QosCMPrePolicyPkt, QosCMDropPkt, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceQosStat. Valid values are DeviceQosID, DeviceID, InterfaceID, StartTime, EndTime, QosPolicyIndex, QosObjectsIndex, QosConfigIndex, QosObjectsType, QosCMName, QosCMDesc, QosCMInfo, QosIfType, QosPolicyDirection, QosIfIndex, QosCMPrePolicyPkt, QosCMDropPkt, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device qos stats, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DeviceID, DeviceQosID, EndTime, InterfaceID, QosCMDesc, QosCMDropPkt, QosCMInfo, QosCMName, QosCMPrePolicyPkt, QosConfigIndex, QosIfIndex, QosIfType, QosObjectsIndex, QosObjectsType, QosPolicyDirection, QosPolicyIndex, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue, StartTime.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_qos_stats: An array of the DeviceQosStat objects that match the specified input criteria.
             :rtype device_qos_stats: Array of DeviceQosStat

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device qos stats matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DeviceID, DeviceQosID, EndTime, InterfaceID, QosCMDesc, QosCMDropPkt, QosCMInfo, QosCMName, QosCMPrePolicyPkt, QosConfigIndex, QosIfIndex, QosIfType, QosObjectsIndex, QosObjectsType, QosPolicyDirection, QosPolicyIndex, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue, StartTime.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier of each device from which Qos was calculated or collected. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceQosID: The operator to apply to the field DeviceQosID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceQosID: The internal NetMRI identifier for the Device Quality of Service. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceQosID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceQosID: If op_DeviceQosID is specified, the field named in this input will be compared to the value in DeviceQosID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceQosID must be specified if op_DeviceQosID is specified.
             :type val_f_DeviceQosID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceQosID: If op_DeviceQosID is specified, this value will be compared to the value in DeviceQosID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceQosID must be specified if op_DeviceQosID is specified.
             :type val_c_DeviceQosID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EndTime: The operator to apply to the field EndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EndTime: The date and time the record was last modified in NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EndTime: If op_EndTime is specified, the field named in this input will be compared to the value in EndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EndTime must be specified if op_EndTime is specified.
             :type val_f_EndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EndTime: If op_EndTime is specified, this value will be compared to the value in EndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EndTime must be specified if op_EndTime is specified.
             :type val_c_EndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_InterfaceID: The operator to apply to the field InterfaceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. InterfaceID: The internal NetMRI identifier of the local interface of the Device Qos Statistics. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_InterfaceID: If op_InterfaceID is specified, the field named in this input will be compared to the value in InterfaceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_f_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_InterfaceID: If op_InterfaceID is specified, this value will be compared to the value in InterfaceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_c_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosCMDesc: The operator to apply to the field QosCMDesc. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosCMDesc: The common description of Qos Statistics of each device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosCMDesc: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosCMDesc: If op_QosCMDesc is specified, the field named in this input will be compared to the value in QosCMDesc using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosCMDesc must be specified if op_QosCMDesc is specified.
             :type val_f_QosCMDesc: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosCMDesc: If op_QosCMDesc is specified, this value will be compared to the value in QosCMDesc using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosCMDesc must be specified if op_QosCMDesc is specified.
             :type val_c_QosCMDesc: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosCMDropPkt: The operator to apply to the field QosCMDropPkt. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosCMDropPkt: The number of common drop packet defined in the Qos statistics of each device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosCMDropPkt: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosCMDropPkt: If op_QosCMDropPkt is specified, the field named in this input will be compared to the value in QosCMDropPkt using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosCMDropPkt must be specified if op_QosCMDropPkt is specified.
             :type val_f_QosCMDropPkt: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosCMDropPkt: If op_QosCMDropPkt is specified, this value will be compared to the value in QosCMDropPkt using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosCMDropPkt must be specified if op_QosCMDropPkt is specified.
             :type val_c_QosCMDropPkt: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosCMInfo: The operator to apply to the field QosCMInfo. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosCMInfo: The common information of Device Qos Statistics. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosCMInfo: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosCMInfo: If op_QosCMInfo is specified, the field named in this input will be compared to the value in QosCMInfo using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosCMInfo must be specified if op_QosCMInfo is specified.
             :type val_f_QosCMInfo: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosCMInfo: If op_QosCMInfo is specified, this value will be compared to the value in QosCMInfo using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosCMInfo must be specified if op_QosCMInfo is specified.
             :type val_c_QosCMInfo: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosCMName: The operator to apply to the field QosCMName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosCMName: The common name of Qos statistics of each device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosCMName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosCMName: If op_QosCMName is specified, the field named in this input will be compared to the value in QosCMName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosCMName must be specified if op_QosCMName is specified.
             :type val_f_QosCMName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosCMName: If op_QosCMName is specified, this value will be compared to the value in QosCMName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosCMName must be specified if op_QosCMName is specified.
             :type val_c_QosCMName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosCMPrePolicyPkt: The operator to apply to the field QosCMPrePolicyPkt. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosCMPrePolicyPkt: The number of common policy packet defined in the Qos statistics of each device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosCMPrePolicyPkt: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosCMPrePolicyPkt: If op_QosCMPrePolicyPkt is specified, the field named in this input will be compared to the value in QosCMPrePolicyPkt using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosCMPrePolicyPkt must be specified if op_QosCMPrePolicyPkt is specified.
             :type val_f_QosCMPrePolicyPkt: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosCMPrePolicyPkt: If op_QosCMPrePolicyPkt is specified, this value will be compared to the value in QosCMPrePolicyPkt using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosCMPrePolicyPkt must be specified if op_QosCMPrePolicyPkt is specified.
             :type val_c_QosCMPrePolicyPkt: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosConfigIndex: The operator to apply to the field QosConfigIndex. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosConfigIndex: The config value of Qos statistics of each device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosConfigIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosConfigIndex: If op_QosConfigIndex is specified, the field named in this input will be compared to the value in QosConfigIndex using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosConfigIndex must be specified if op_QosConfigIndex is specified.
             :type val_f_QosConfigIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosConfigIndex: If op_QosConfigIndex is specified, this value will be compared to the value in QosConfigIndex using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosConfigIndex must be specified if op_QosConfigIndex is specified.
             :type val_c_QosConfigIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosIfIndex: The operator to apply to the field QosIfIndex. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosIfIndex: The current value of the Device Qos Statistics. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosIfIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosIfIndex: If op_QosIfIndex is specified, the field named in this input will be compared to the value in QosIfIndex using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosIfIndex must be specified if op_QosIfIndex is specified.
             :type val_f_QosIfIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosIfIndex: If op_QosIfIndex is specified, this value will be compared to the value in QosIfIndex using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosIfIndex must be specified if op_QosIfIndex is specified.
             :type val_c_QosIfIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosIfType: The operator to apply to the field QosIfType. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosIfType: The type of Device Qos Statistics. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosIfType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosIfType: If op_QosIfType is specified, the field named in this input will be compared to the value in QosIfType using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosIfType must be specified if op_QosIfType is specified.
             :type val_f_QosIfType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosIfType: If op_QosIfType is specified, this value will be compared to the value in QosIfType using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosIfType must be specified if op_QosIfType is specified.
             :type val_c_QosIfType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosObjectsIndex: The operator to apply to the field QosObjectsIndex. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosObjectsIndex: The object index of Qos statistics of each device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosObjectsIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosObjectsIndex: If op_QosObjectsIndex is specified, the field named in this input will be compared to the value in QosObjectsIndex using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosObjectsIndex must be specified if op_QosObjectsIndex is specified.
             :type val_f_QosObjectsIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosObjectsIndex: If op_QosObjectsIndex is specified, this value will be compared to the value in QosObjectsIndex using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosObjectsIndex must be specified if op_QosObjectsIndex is specified.
             :type val_c_QosObjectsIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosObjectsType: The operator to apply to the field QosObjectsType. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosObjectsType: The NetMRI-determined the object type of Device Qos Statistics. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosObjectsType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosObjectsType: If op_QosObjectsType is specified, the field named in this input will be compared to the value in QosObjectsType using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosObjectsType must be specified if op_QosObjectsType is specified.
             :type val_f_QosObjectsType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosObjectsType: If op_QosObjectsType is specified, this value will be compared to the value in QosObjectsType using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosObjectsType must be specified if op_QosObjectsType is specified.
             :type val_c_QosObjectsType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosPolicyDirection: The operator to apply to the field QosPolicyDirection. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosPolicyDirection: Describes the direction of policy defined in the Qos. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosPolicyDirection: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosPolicyDirection: If op_QosPolicyDirection is specified, the field named in this input will be compared to the value in QosPolicyDirection using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosPolicyDirection must be specified if op_QosPolicyDirection is specified.
             :type val_f_QosPolicyDirection: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosPolicyDirection: If op_QosPolicyDirection is specified, this value will be compared to the value in QosPolicyDirection using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosPolicyDirection must be specified if op_QosPolicyDirection is specified.
             :type val_c_QosPolicyDirection: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosPolicyIndex: The operator to apply to the field QosPolicyIndex. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosPolicyIndex: The policy value of Quality of service in each device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosPolicyIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosPolicyIndex: If op_QosPolicyIndex is specified, the field named in this input will be compared to the value in QosPolicyIndex using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosPolicyIndex must be specified if op_QosPolicyIndex is specified.
             :type val_f_QosPolicyIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosPolicyIndex: If op_QosPolicyIndex is specified, this value will be compared to the value in QosPolicyIndex using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosPolicyIndex must be specified if op_QosPolicyIndex is specified.
             :type val_c_QosPolicyIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosSetCfgIpDSCPValue: The operator to apply to the field QosSetCfgIpDSCPValue. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosSetCfgIpDSCPValue: Defines the configuration IP address of device statistics. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosSetCfgIpDSCPValue: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosSetCfgIpDSCPValue: If op_QosSetCfgIpDSCPValue is specified, the field named in this input will be compared to the value in QosSetCfgIpDSCPValue using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosSetCfgIpDSCPValue must be specified if op_QosSetCfgIpDSCPValue is specified.
             :type val_f_QosSetCfgIpDSCPValue: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosSetCfgIpDSCPValue: If op_QosSetCfgIpDSCPValue is specified, this value will be compared to the value in QosSetCfgIpDSCPValue using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosSetCfgIpDSCPValue must be specified if op_QosSetCfgIpDSCPValue is specified.
             :type val_c_QosSetCfgIpDSCPValue: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_QosSetCfgIpPrecedenceValue: The operator to apply to the field QosSetCfgIpPrecedenceValue. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. QosSetCfgIpPrecedenceValue: The precedence value of configuration IP address. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_QosSetCfgIpPrecedenceValue: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_QosSetCfgIpPrecedenceValue: If op_QosSetCfgIpPrecedenceValue is specified, the field named in this input will be compared to the value in QosSetCfgIpPrecedenceValue using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_QosSetCfgIpPrecedenceValue must be specified if op_QosSetCfgIpPrecedenceValue is specified.
             :type val_f_QosSetCfgIpPrecedenceValue: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_QosSetCfgIpPrecedenceValue: If op_QosSetCfgIpPrecedenceValue is specified, this value will be compared to the value in QosSetCfgIpPrecedenceValue using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_QosSetCfgIpPrecedenceValue must be specified if op_QosSetCfgIpPrecedenceValue is specified.
             :type val_c_QosSetCfgIpPrecedenceValue: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_StartTime: The operator to apply to the field StartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. StartTime: The date and time the record is initially created in the NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_StartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_StartTime: If op_StartTime is specified, the field named in this input will be compared to the value in StartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_StartTime must be specified if op_StartTime is specified.
             :type val_f_StartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_StartTime: If op_StartTime is specified, this value will be compared to the value in StartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_StartTime must be specified if op_StartTime is specified.
             :type val_c_StartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` today

             :param starttime: The data returned will represent the device qos stats with this date and time as lower boundary. If omitted, the result will indicate the most recently collected data.
             :type starttime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` tomorrow

             :param endtime: The data returned will represent the device qos stats with this date and time as upper boundary. If omitted, the result will indicate the most recently collected data.
             :type endtime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceQosID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceQosID. Valid values are DeviceQosID, DeviceID, InterfaceID, StartTime, EndTime, QosPolicyIndex, QosObjectsIndex, QosConfigIndex, QosObjectsType, QosCMName, QosCMDesc, QosCMInfo, QosIfType, QosPolicyDirection, QosIfIndex, QosCMPrePolicyPkt, QosCMDropPkt, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceQosStat. Valid values are DeviceQosID, DeviceID, InterfaceID, StartTime, EndTime, QosPolicyIndex, QosObjectsIndex, QosConfigIndex, QosObjectsType, QosCMName, QosCMDesc, QosCMInfo, QosIfType, QosPolicyDirection, QosIfIndex, QosCMPrePolicyPkt, QosCMDropPkt, QosSetCfgIpDSCPValue, QosSetCfgIpPrecedenceValue. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_qos_stats: An array of the DeviceQosStat objects that match the specified input criteria.
             :rtype device_qos_stats: Array of DeviceQosStat

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)



from ..broker import Broker


class PathAnalysisBroker(Broker):
    controller = "path_analysis"

    def create(self, **kwargs):
        """Initiates a path calculation.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param sources: The source address specifications.
             :type sources: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param destinations: The destination address specifications.
             :type destinations: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param virtual_network_id: The internal identifier for the network which the device is associated to.
             :type virtual_network_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device.
             :type DeviceID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return path_calculation_id: The identifier for this path calculation.
             :rtype path_calculation_id: String

            """

        return self.api_request(self._get_method_fullname("create"), kwargs)

    def continue_path(self, **kwargs):
        """Continues a path calculation.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_analysis_id: The identifier for the row from set of paths.
             :type path_analysis_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to continue the path from.
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param virtual_network_id: The internal NetMRI identifier for the network view which device belongs to
             :type virtual_network_id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return path_calculation_id: The identifier for this path calculation.
             :rtype path_calculation_id: String

            """

        return self.api_request(self._get_method_fullname("continue_path"), kwargs)

    def row_status(self, **kwargs):
        """The current status of a row from set of paths.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param PathAnalysisID: The identifier for the row from set of paths.
             :type PathAnalysisID: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return status: The current status of a row from set of paths (Running, Ready, Error).
             :rtype status: String

            """

        return self.api_request(self._get_method_fullname("row_status"), kwargs)

    def status(self, **kwargs):
        """The overall status of a path calculation.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return status: The overall status of a path calculation (Running, Ready, Error).
             :rtype status: String

            """

        return self.api_request(self._get_method_fullname("status"), kwargs)

    def cancel(self, **kwargs):
        """Cancel calculation of paths.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("cancel"), kwargs)

    def compute_rule_list(self, **kwargs):
        """Compute rule list for any link on selected path.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_analysis_id: The identifier for the row from set of paths.
             :type path_analysis_id: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return rule_list: The list of rule-list associated with a record.
             :rtype rule_list: Array

            """

        return self.api_request(self._get_method_fullname("compute_rule_list"), kwargs)

    def compute_and_save_rule_list(self, **kwargs):
        """Compute rule list for any link on selected path and save it to the selected workbook.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_analysis_id: The identifier for the row from set of paths.
             :type path_analysis_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param workbook_id: The internal NetMRI identifier of the workbook.
             :type workbook_id: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("compute_and_save_rule_list"), kwargs)

    def compare_computed_rule_list(self, **kwargs):
        """Compare computed rule list for any link to the selected workbook.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_analysis_id: The identifier for the row from set of paths.
             :type path_analysis_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param workbook_id: The internal NetMRI identifier of the workbook.
             :type workbook_id: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("compare_computed_rule_list"), kwargs)

    def build_path_tree(self, **kwargs):
        """Build tree representation of computed path.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param path_calculation_id: The identifier for the path calculation.
             :type path_calculation_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param PathAnalysisID: The identifier for the row from set of paths.
             :type PathAnalysisID: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return path_tree: Computed path in the tree view
             :rtype path_tree: String

            """

        return self.api_request(self._get_method_fullname("build_path_tree"), kwargs)



from ..remote import RemoteModel
from infoblox_netmri.utils.utils import check_api_availability


class EffectivePolicyRuleRemote(RemoteModel):
    """
    The policy rules, as they were defined at the time of policy evaluation. The rules described in here correspond to the policy rule results expressed in the DevicePolicyRule and other results models.


    |  ``DataSourceID:`` The internal NetMRI identifier for the collector NetMRI that collected this data record.
    |  ``attribute type:`` number


    |  ``PolicyRuleID:`` The internal NetMRI identifier for this effective policy rule.
    |  ``attribute type:`` number

    |  ``PolicyRuleStartTime:`` The starting effective time of this record.
    |  ``attribute type:`` datetime

    |  ``PolicyRuleEndTime:`` The ending effective time of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``PolicyRuleChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    |  ``PolicyRuleTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``PolicyRuleFirstSeenTime:`` The date and time when this policy rule was first seen on the NetMRI.
    |  ``attribute type:`` datetime

    |  ``PolicyRuleName:`` The long name of the policy rule.
    |  ``attribute type:`` string

    |  ``PolicyRuleDescription:`` The description of the policy rule at the time of evaluation.
    |  ``attribute type:`` string

    |  ``PolicyRuleAuthor:`` The author of the policy rule at the time of evaluation.
    |  ``attribute type:`` string

    |  ``PolicyRuleSetFilter:`` The XML SetFilter used to determine if this rule applies to a specific device.
    |  ``attribute type:`` string

    |  ``PolicyRuleRuleLogic:`` The XML policy rule logic.
    |  ``attribute type:`` string

    |  ``PolicyRuleSeverity:`` The severity level (info, warning, or error) for a violation of this rule.
    |  ``attribute type:`` string

    |  ``PolicyRuleActionAfterExec:`` Not used.
    |  ``attribute type:`` string

    |  ``PolicyRuleCreatedAt:`` The date and time the policy rule was first added to NetMRI.
    |  ``attribute type:`` string

    |  ``PolicyRuleUpdatedAt:`` The date and time the policy rule was last updated in NetMRI.
    |  ``attribute type:`` string

    |  ``PolicyRuleRemediation:`` The textual remediation description associated with the rule.
    |  ``attribute type:`` string

    |  ``PolicyRuleShortName:`` The policy rule short name, used on the policy status display.
    |  ``attribute type:`` string

    |  ``PolicyRuleReadOnlyInd:`` A flag indicating whether this is a read-only policy rule.
    |  ``attribute type:`` bool


    |  ``policy_rule_set_filter_text:`` Returns a human-readable text version of the policy rule set filter.
    |  ``attribute type:`` string

    |  ``policy_rule_rule_logic_text:`` Returns a human readable text version of the policy rule logic.
    |  ``attribute type:`` string

    """

    properties = ("DataSourceID",
                  "PolicyRuleID",
                  "PolicyRuleStartTime",
                  "PolicyRuleEndTime",
                  "PolicyRuleChangedCols",
                  "PolicyRuleTimestamp",
                  "PolicyRuleFirstSeenTime",
                  "PolicyRuleName",
                  "PolicyRuleDescription",
                  "PolicyRuleAuthor",
                  "PolicyRuleSetFilter",
                  "PolicyRuleRuleLogic",
                  "PolicyRuleSeverity",
                  "PolicyRuleActionAfterExec",
                  "PolicyRuleCreatedAt",
                  "PolicyRuleUpdatedAt",
                  "PolicyRuleRemediation",
                  "PolicyRuleShortName",
                  "PolicyRuleReadOnlyInd",
                  "policy_rule_set_filter_text",
                  "policy_rule_rule_logic_text",
                  )

    @property
    @check_api_availability
    def data_source(self):
        """
        The collector NetMRI that collected this data record.
        ``attribute type:`` model
        """
        return self.broker.data_source(**{"PolicyRuleID": self.PolicyRuleID})

    @property
    @check_api_availability
    def devices(self):
        """
        The devices against which this rule was evaluated.
        ``attribute type:`` model
        """
        return self.broker.devices(**{"PolicyRuleID": self.PolicyRuleID})



from ..remote import RemoteModel


class DeviceViewerBridgeDomainsGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``tenant_name:`` none
    |  ``attribute type:`` string

    |  ``tenant_dn:`` none
    |  ``attribute type:`` string

    |  ``bridge_domain:`` none
    |  ``attribute type:`` string

    |  ``bridge_domain_dn:`` none
    |  ``attribute type:`` string

    |  ``vrf_name:`` none
    |  ``attribute type:`` string

    |  ``vrf_dn:`` none
    |  ``attribute type:`` string

    |  ``epg_name:`` none
    |  ``attribute type:`` string

    |  ``epg_dn:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "tenant_name",
                  "tenant_dn",
                  "bridge_domain",
                  "bridge_domain_dn",
                  "vrf_name",
                  "vrf_dn",
                  "epg_name",
                  "epg_dn",
                  )



from ..remote import RemoteModel


class EventNetworkAnalysisGridRemote(RemoteModel):
    """



    |  ``EventID:`` none
    |  ``attribute type:`` string

    |  ``EventCategory:`` none
    |  ``attribute type:`` string

    |  ``EventCategoryID:`` none
    |  ``attribute type:`` string

    |  ``EventTimestamp:`` none
    |  ``attribute type:`` string

    """

    properties = ("EventID",
                  "EventCategory",
                  "EventCategoryID",
                  "EventTimestamp",
                  )



from ..remote import RemoteModel


class WirelessHotStandbyGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``WlsHotSbTimestamp:`` none
    |  ``attribute type:`` string

    |  ``MonitoredIPDotted:`` none
    |  ``attribute type:`` string

    |  ``MonitoredIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``MonitoredDevice:`` none
    |  ``attribute type:`` string

    |  ``MonitoredDeviceID:`` none
    |  ``attribute type:`` string

    |  ``MonitoredDeviceType:`` none
    |  ``attribute type:`` string

    |  ``WlsHotSbMAC:`` none
    |  ``attribute type:`` string

    |  ``WlsHotSbInd:`` none
    |  ``attribute type:`` string

    |  ``WlsHotSbStatus:`` none
    |  ``attribute type:`` string

    |  ``WlsHotSbState:`` none
    |  ``attribute type:`` string

    |  ``WlsHotSbPollingFeq:`` none
    |  ``attribute type:`` string

    |  ``WlsHotSbPollingTimeout:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "WlsHotSbTimestamp",
                  "MonitoredIPDotted",
                  "MonitoredIPNumeric",
                  "MonitoredDevice",
                  "MonitoredDeviceID",
                  "MonitoredDeviceType",
                  "WlsHotSbMAC",
                  "WlsHotSbInd",
                  "WlsHotSbStatus",
                  "WlsHotSbState",
                  "WlsHotSbPollingFeq",
                  "WlsHotSbPollingTimeout",
                  )



from ..broker import Broker


class SpmHistoryDeviceHistoryGridBroker(Broker):
    controller = "spm_history_device_history_grids"

    def index(self, **kwargs):
        """Lists the available spm history device history grids. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: An internal NetMRI identifier for the device.
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` today

             :param starttime: The data returned will represent the spm history device history grids with this date and time as lower boundary. If omitted, the result will indicate the most recently collected data.
             :type starttime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` tomorrow

             :param endtime: The data returned will represent the spm history device history grids with this date and time as upper boundary. If omitted, the result will indicate the most recently collected data.
             :type endtime: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, FirstSeen, LastSeen, DeviceID, DeviceName, DeviceIPDotted, DeviceIPNumeric, VirtualNetworkID, Network, DeviceDNSName, DeviceSysLocation, DeviceSysDescr, DeviceVendor, DeviceModel, PhysicalSerialNum, DeviceType, PollDuration.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each SpmHistoryDeviceHistoryGrid. Valid values are id, FirstSeen, LastSeen, DeviceID, DeviceName, DeviceIPDotted, DeviceIPNumeric, VirtualNetworkID, Network, DeviceDNSName, DeviceSysLocation, DeviceSysDescr, DeviceVendor, DeviceModel, PhysicalSerialNum, DeviceType, PollDuration. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param refresh_ind: If true, the grid will be regenerated, rather than using any available cached grid data.
             :type refresh_ind: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param async_ind: If true and if grid data is not yet available, it will return immediately with 202 status. User should retry again later.
             :type async_ind: Boolean

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return spm_history_device_history_grids: An array of the SpmHistoryDeviceHistoryGrid objects that match the specified input criteria.
             :rtype spm_history_device_history_grids: Array of SpmHistoryDeviceHistoryGrid

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return summary: A summary of calculation of selected columns, when applicable.
             :rtype summary: Hash

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)



from ..broker import Broker


class DataCollectionStatusBroker(Broker):
    controller = "data_collection_statuses"

    def index(self, **kwargs):
        """Lists the available data collection statuses. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device on which collection applied.
             :type DeviceID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data collection status methods. The listed methods will be called on each data collection status returned and included in the output. Available methods are: system, cpu, memory, vlans, forwarding, environmental, inventory, arp, route, neighbor, config, access, vrf, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceID. Valid values are DeviceID, SystemInd, CPUInd, MemoryInd, VlansInd, ForwardingInd, EnvironmentalInd, InventoryInd, ARPInd, RouteInd, NeighborInd, ConfigInd, AccessInd, VrfInd, SystemTimestamp, CPUTimestamp, MemoryTimestamp, VlansTimestamp, ForwardingTimestamp, EnvironmentalTimestamp, InventoryTimestamp, ARPTimestamp, RouteTimestamp, NeighborTimestamp, ConfigTimestamp, AccessTimestamp, VrfTimestamp.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DataCollectionStatus. Valid values are DeviceID, SystemInd, CPUInd, MemoryInd, VlansInd, ForwardingInd, EnvironmentalInd, InventoryInd, ARPInd, RouteInd, NeighborInd, ConfigInd, AccessInd, VrfInd, SystemTimestamp, CPUTimestamp, MemoryTimestamp, VlansTimestamp, ForwardingTimestamp, EnvironmentalTimestamp, InventoryTimestamp, ARPTimestamp, RouteTimestamp, NeighborTimestamp, ConfigTimestamp, AccessTimestamp, VrfTimestamp. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_collection_statuses: An array of the DataCollectionStatus objects that match the specified input criteria.
             :rtype data_collection_statuses: Array of DataCollectionStatus

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def show(self, **kwargs):
        """Shows the details for the specified data collection status.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device on which collection applied.
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data collection status methods. The listed methods will be called on each data collection status returned and included in the output. Available methods are: system, cpu, memory, vlans, forwarding, environmental, inventory, arp, route, neighbor, config, access, vrf, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_collection_status: The data collection status identified by the specified DeviceID.
             :rtype data_collection_status: DataCollectionStatus

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def search(self, **kwargs):
        """Lists the available data collection statuses matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ARPInd: The indicator of collection of the arp information.
             :type ARPInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ARPTimestamp: The date and time of last collect of the arp information.
             :type ARPTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param AccessInd: The indicator of collection of the filtering access information.
             :type AccessInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param AccessTimestamp: The date and time of last collect of the filtering access information.
             :type AccessTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param CPUInd: The indicator of collection of cpu information.
             :type CPUInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param CPUTimestamp: The date and time of last collect of the cpu information.
             :type CPUTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ConfigInd: The indicator of collection of the configuration information.
             :type ConfigInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ConfigTimestamp: The date and time of last collect of the configuration information.
             :type ConfigTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device on which collection applied.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EnvironmentalInd: The indicator of collection of environmental information.
             :type EnvironmentalInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EnvironmentalTimestamp: The date and time of last collect of the environmental information.
             :type EnvironmentalTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ForwardingInd: The indicator of collection of forwarding information.
             :type ForwardingInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ForwardingTimestamp: The date and time of last collect of the forwarding information.
             :type ForwardingTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InventoryInd: The indicator of collection of the inventory information.
             :type InventoryInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InventoryTimestamp: The date and time of last collect of the inventory information.
             :type InventoryTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param MemoryInd: The indicator of collection of memory information.
             :type MemoryInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param MemoryTimestamp: The date and time of last collect of the memory information.
             :type MemoryTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborInd: The indicator of collection of the neighborhood information.
             :type NeighborInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborTimestamp: The date and time of last collect of the neighborhood information.
             :type NeighborTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param RouteInd: The indicator of collection of the route information.
             :type RouteInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param RouteTimestamp: The date and time of last collect of the route information.
             :type RouteTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SystemInd: The indicator of collection of system information.
             :type SystemInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SystemTimestamp: The date and time of last collect of the system information.
             :type SystemTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VlansInd: The indicator of collection of virtual LAN information.
             :type VlansInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VlansTimestamp: The date and time of last collect of the virtual LAN information.
             :type VlansTimestamp: Array of DateTime

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VrfInd: The indicator of collection of virtual network information.
             :type VrfInd: Array of String

            |  ``api version min:`` 2.7
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VrfTimestamp: The date and time of last collect of the virtual network information.
             :type VrfTimestamp: Array of DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data collection status methods. The listed methods will be called on each data collection status returned and included in the output. Available methods are: system, cpu, memory, vlans, forwarding, environmental, inventory, arp, route, neighbor, config, access, vrf, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceID. Valid values are DeviceID, SystemInd, CPUInd, MemoryInd, VlansInd, ForwardingInd, EnvironmentalInd, InventoryInd, ARPInd, RouteInd, NeighborInd, ConfigInd, AccessInd, VrfInd, SystemTimestamp, CPUTimestamp, MemoryTimestamp, VlansTimestamp, ForwardingTimestamp, EnvironmentalTimestamp, InventoryTimestamp, ARPTimestamp, RouteTimestamp, NeighborTimestamp, ConfigTimestamp, AccessTimestamp, VrfTimestamp.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DataCollectionStatus. Valid values are DeviceID, SystemInd, CPUInd, MemoryInd, VlansInd, ForwardingInd, EnvironmentalInd, InventoryInd, ARPInd, RouteInd, NeighborInd, ConfigInd, AccessInd, VrfInd, SystemTimestamp, CPUTimestamp, MemoryTimestamp, VlansTimestamp, ForwardingTimestamp, EnvironmentalTimestamp, InventoryTimestamp, ARPTimestamp, RouteTimestamp, NeighborTimestamp, ConfigTimestamp, AccessTimestamp, VrfTimestamp. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against data collection statuses, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: ARPInd, ARPTimestamp, AccessInd, AccessTimestamp, CPUInd, CPUTimestamp, ConfigInd, ConfigTimestamp, DeviceID, EnvironmentalInd, EnvironmentalTimestamp, ForwardingInd, ForwardingTimestamp, InventoryInd, InventoryTimestamp, MemoryInd, MemoryTimestamp, NeighborInd, NeighborTimestamp, RouteInd, RouteTimestamp, SystemInd, SystemTimestamp, VlansInd, VlansTimestamp, VrfInd, VrfTimestamp.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_collection_statuses: An array of the DataCollectionStatus objects that match the specified input criteria.
             :rtype data_collection_statuses: Array of DataCollectionStatus

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available data collection statuses matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: ARPInd, ARPTimestamp, AccessInd, AccessTimestamp, CPUInd, CPUTimestamp, ConfigInd, ConfigTimestamp, DeviceID, EnvironmentalInd, EnvironmentalTimestamp, ForwardingInd, ForwardingTimestamp, InventoryInd, InventoryTimestamp, MemoryInd, MemoryTimestamp, NeighborInd, NeighborTimestamp, RouteInd, RouteTimestamp, SystemInd, SystemTimestamp, VlansInd, VlansTimestamp, VrfInd, VrfTimestamp.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ARPInd: The operator to apply to the field ARPInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ARPInd: The indicator of collection of the arp information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ARPInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ARPInd: If op_ARPInd is specified, the field named in this input will be compared to the value in ARPInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ARPInd must be specified if op_ARPInd is specified.
             :type val_f_ARPInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ARPInd: If op_ARPInd is specified, this value will be compared to the value in ARPInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ARPInd must be specified if op_ARPInd is specified.
             :type val_c_ARPInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ARPTimestamp: The operator to apply to the field ARPTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ARPTimestamp: The date and time of last collect of the arp information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ARPTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ARPTimestamp: If op_ARPTimestamp is specified, the field named in this input will be compared to the value in ARPTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ARPTimestamp must be specified if op_ARPTimestamp is specified.
             :type val_f_ARPTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ARPTimestamp: If op_ARPTimestamp is specified, this value will be compared to the value in ARPTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ARPTimestamp must be specified if op_ARPTimestamp is specified.
             :type val_c_ARPTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_AccessInd: The operator to apply to the field AccessInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. AccessInd: The indicator of collection of the filtering access information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_AccessInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_AccessInd: If op_AccessInd is specified, the field named in this input will be compared to the value in AccessInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_AccessInd must be specified if op_AccessInd is specified.
             :type val_f_AccessInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_AccessInd: If op_AccessInd is specified, this value will be compared to the value in AccessInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_AccessInd must be specified if op_AccessInd is specified.
             :type val_c_AccessInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_AccessTimestamp: The operator to apply to the field AccessTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. AccessTimestamp: The date and time of last collect of the filtering access information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_AccessTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_AccessTimestamp: If op_AccessTimestamp is specified, the field named in this input will be compared to the value in AccessTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_AccessTimestamp must be specified if op_AccessTimestamp is specified.
             :type val_f_AccessTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_AccessTimestamp: If op_AccessTimestamp is specified, this value will be compared to the value in AccessTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_AccessTimestamp must be specified if op_AccessTimestamp is specified.
             :type val_c_AccessTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_CPUInd: The operator to apply to the field CPUInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. CPUInd: The indicator of collection of cpu information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_CPUInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_CPUInd: If op_CPUInd is specified, the field named in this input will be compared to the value in CPUInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_CPUInd must be specified if op_CPUInd is specified.
             :type val_f_CPUInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_CPUInd: If op_CPUInd is specified, this value will be compared to the value in CPUInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_CPUInd must be specified if op_CPUInd is specified.
             :type val_c_CPUInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_CPUTimestamp: The operator to apply to the field CPUTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. CPUTimestamp: The date and time of last collect of the cpu information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_CPUTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_CPUTimestamp: If op_CPUTimestamp is specified, the field named in this input will be compared to the value in CPUTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_CPUTimestamp must be specified if op_CPUTimestamp is specified.
             :type val_f_CPUTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_CPUTimestamp: If op_CPUTimestamp is specified, this value will be compared to the value in CPUTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_CPUTimestamp must be specified if op_CPUTimestamp is specified.
             :type val_c_CPUTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ConfigInd: The operator to apply to the field ConfigInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ConfigInd: The indicator of collection of the configuration information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ConfigInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ConfigInd: If op_ConfigInd is specified, the field named in this input will be compared to the value in ConfigInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ConfigInd must be specified if op_ConfigInd is specified.
             :type val_f_ConfigInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ConfigInd: If op_ConfigInd is specified, this value will be compared to the value in ConfigInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ConfigInd must be specified if op_ConfigInd is specified.
             :type val_c_ConfigInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ConfigTimestamp: The operator to apply to the field ConfigTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ConfigTimestamp: The date and time of last collect of the configuration information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ConfigTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ConfigTimestamp: If op_ConfigTimestamp is specified, the field named in this input will be compared to the value in ConfigTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ConfigTimestamp must be specified if op_ConfigTimestamp is specified.
             :type val_f_ConfigTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ConfigTimestamp: If op_ConfigTimestamp is specified, this value will be compared to the value in ConfigTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ConfigTimestamp must be specified if op_ConfigTimestamp is specified.
             :type val_c_ConfigTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device on which collection applied. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EnvironmentalInd: The operator to apply to the field EnvironmentalInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EnvironmentalInd: The indicator of collection of environmental information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EnvironmentalInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EnvironmentalInd: If op_EnvironmentalInd is specified, the field named in this input will be compared to the value in EnvironmentalInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EnvironmentalInd must be specified if op_EnvironmentalInd is specified.
             :type val_f_EnvironmentalInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EnvironmentalInd: If op_EnvironmentalInd is specified, this value will be compared to the value in EnvironmentalInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EnvironmentalInd must be specified if op_EnvironmentalInd is specified.
             :type val_c_EnvironmentalInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EnvironmentalTimestamp: The operator to apply to the field EnvironmentalTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EnvironmentalTimestamp: The date and time of last collect of the environmental information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EnvironmentalTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EnvironmentalTimestamp: If op_EnvironmentalTimestamp is specified, the field named in this input will be compared to the value in EnvironmentalTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EnvironmentalTimestamp must be specified if op_EnvironmentalTimestamp is specified.
             :type val_f_EnvironmentalTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EnvironmentalTimestamp: If op_EnvironmentalTimestamp is specified, this value will be compared to the value in EnvironmentalTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EnvironmentalTimestamp must be specified if op_EnvironmentalTimestamp is specified.
             :type val_c_EnvironmentalTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ForwardingInd: The operator to apply to the field ForwardingInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ForwardingInd: The indicator of collection of forwarding information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ForwardingInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ForwardingInd: If op_ForwardingInd is specified, the field named in this input will be compared to the value in ForwardingInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ForwardingInd must be specified if op_ForwardingInd is specified.
             :type val_f_ForwardingInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ForwardingInd: If op_ForwardingInd is specified, this value will be compared to the value in ForwardingInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ForwardingInd must be specified if op_ForwardingInd is specified.
             :type val_c_ForwardingInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ForwardingTimestamp: The operator to apply to the field ForwardingTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ForwardingTimestamp: The date and time of last collect of the forwarding information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ForwardingTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ForwardingTimestamp: If op_ForwardingTimestamp is specified, the field named in this input will be compared to the value in ForwardingTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ForwardingTimestamp must be specified if op_ForwardingTimestamp is specified.
             :type val_f_ForwardingTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ForwardingTimestamp: If op_ForwardingTimestamp is specified, this value will be compared to the value in ForwardingTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ForwardingTimestamp must be specified if op_ForwardingTimestamp is specified.
             :type val_c_ForwardingTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_InventoryInd: The operator to apply to the field InventoryInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. InventoryInd: The indicator of collection of the inventory information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_InventoryInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_InventoryInd: If op_InventoryInd is specified, the field named in this input will be compared to the value in InventoryInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_InventoryInd must be specified if op_InventoryInd is specified.
             :type val_f_InventoryInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_InventoryInd: If op_InventoryInd is specified, this value will be compared to the value in InventoryInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_InventoryInd must be specified if op_InventoryInd is specified.
             :type val_c_InventoryInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_InventoryTimestamp: The operator to apply to the field InventoryTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. InventoryTimestamp: The date and time of last collect of the inventory information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_InventoryTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_InventoryTimestamp: If op_InventoryTimestamp is specified, the field named in this input will be compared to the value in InventoryTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_InventoryTimestamp must be specified if op_InventoryTimestamp is specified.
             :type val_f_InventoryTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_InventoryTimestamp: If op_InventoryTimestamp is specified, this value will be compared to the value in InventoryTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_InventoryTimestamp must be specified if op_InventoryTimestamp is specified.
             :type val_c_InventoryTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_MemoryInd: The operator to apply to the field MemoryInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. MemoryInd: The indicator of collection of memory information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_MemoryInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_MemoryInd: If op_MemoryInd is specified, the field named in this input will be compared to the value in MemoryInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_MemoryInd must be specified if op_MemoryInd is specified.
             :type val_f_MemoryInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_MemoryInd: If op_MemoryInd is specified, this value will be compared to the value in MemoryInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_MemoryInd must be specified if op_MemoryInd is specified.
             :type val_c_MemoryInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_MemoryTimestamp: The operator to apply to the field MemoryTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. MemoryTimestamp: The date and time of last collect of the memory information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_MemoryTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_MemoryTimestamp: If op_MemoryTimestamp is specified, the field named in this input will be compared to the value in MemoryTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_MemoryTimestamp must be specified if op_MemoryTimestamp is specified.
             :type val_f_MemoryTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_MemoryTimestamp: If op_MemoryTimestamp is specified, this value will be compared to the value in MemoryTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_MemoryTimestamp must be specified if op_MemoryTimestamp is specified.
             :type val_c_MemoryTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_NeighborInd: The operator to apply to the field NeighborInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. NeighborInd: The indicator of collection of the neighborhood information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_NeighborInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_NeighborInd: If op_NeighborInd is specified, the field named in this input will be compared to the value in NeighborInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_NeighborInd must be specified if op_NeighborInd is specified.
             :type val_f_NeighborInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_NeighborInd: If op_NeighborInd is specified, this value will be compared to the value in NeighborInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_NeighborInd must be specified if op_NeighborInd is specified.
             :type val_c_NeighborInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_NeighborTimestamp: The operator to apply to the field NeighborTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. NeighborTimestamp: The date and time of last collect of the neighborhood information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_NeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_NeighborTimestamp: If op_NeighborTimestamp is specified, the field named in this input will be compared to the value in NeighborTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_NeighborTimestamp must be specified if op_NeighborTimestamp is specified.
             :type val_f_NeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_NeighborTimestamp: If op_NeighborTimestamp is specified, this value will be compared to the value in NeighborTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_NeighborTimestamp must be specified if op_NeighborTimestamp is specified.
             :type val_c_NeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_RouteInd: The operator to apply to the field RouteInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. RouteInd: The indicator of collection of the route information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_RouteInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_RouteInd: If op_RouteInd is specified, the field named in this input will be compared to the value in RouteInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_RouteInd must be specified if op_RouteInd is specified.
             :type val_f_RouteInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_RouteInd: If op_RouteInd is specified, this value will be compared to the value in RouteInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_RouteInd must be specified if op_RouteInd is specified.
             :type val_c_RouteInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_RouteTimestamp: The operator to apply to the field RouteTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. RouteTimestamp: The date and time of last collect of the route information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_RouteTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_RouteTimestamp: If op_RouteTimestamp is specified, the field named in this input will be compared to the value in RouteTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_RouteTimestamp must be specified if op_RouteTimestamp is specified.
             :type val_f_RouteTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_RouteTimestamp: If op_RouteTimestamp is specified, this value will be compared to the value in RouteTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_RouteTimestamp must be specified if op_RouteTimestamp is specified.
             :type val_c_RouteTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SystemInd: The operator to apply to the field SystemInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SystemInd: The indicator of collection of system information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SystemInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SystemInd: If op_SystemInd is specified, the field named in this input will be compared to the value in SystemInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SystemInd must be specified if op_SystemInd is specified.
             :type val_f_SystemInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SystemInd: If op_SystemInd is specified, this value will be compared to the value in SystemInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SystemInd must be specified if op_SystemInd is specified.
             :type val_c_SystemInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SystemTimestamp: The operator to apply to the field SystemTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SystemTimestamp: The date and time of last collect of the system information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SystemTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SystemTimestamp: If op_SystemTimestamp is specified, the field named in this input will be compared to the value in SystemTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SystemTimestamp must be specified if op_SystemTimestamp is specified.
             :type val_f_SystemTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SystemTimestamp: If op_SystemTimestamp is specified, this value will be compared to the value in SystemTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SystemTimestamp must be specified if op_SystemTimestamp is specified.
             :type val_c_SystemTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VlansInd: The operator to apply to the field VlansInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VlansInd: The indicator of collection of virtual LAN information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VlansInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VlansInd: If op_VlansInd is specified, the field named in this input will be compared to the value in VlansInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VlansInd must be specified if op_VlansInd is specified.
             :type val_f_VlansInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VlansInd: If op_VlansInd is specified, this value will be compared to the value in VlansInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VlansInd must be specified if op_VlansInd is specified.
             :type val_c_VlansInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VlansTimestamp: The operator to apply to the field VlansTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VlansTimestamp: The date and time of last collect of the virtual LAN information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VlansTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VlansTimestamp: If op_VlansTimestamp is specified, the field named in this input will be compared to the value in VlansTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VlansTimestamp must be specified if op_VlansTimestamp is specified.
             :type val_f_VlansTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VlansTimestamp: If op_VlansTimestamp is specified, this value will be compared to the value in VlansTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VlansTimestamp must be specified if op_VlansTimestamp is specified.
             :type val_c_VlansTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VrfInd: The operator to apply to the field VrfInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VrfInd: The indicator of collection of virtual network information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VrfInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VrfInd: If op_VrfInd is specified, the field named in this input will be compared to the value in VrfInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VrfInd must be specified if op_VrfInd is specified.
             :type val_f_VrfInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VrfInd: If op_VrfInd is specified, this value will be compared to the value in VrfInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VrfInd must be specified if op_VrfInd is specified.
             :type val_c_VrfInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VrfTimestamp: The operator to apply to the field VrfTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VrfTimestamp: The date and time of last collect of the virtual network information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VrfTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VrfTimestamp: If op_VrfTimestamp is specified, the field named in this input will be compared to the value in VrfTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VrfTimestamp must be specified if op_VrfTimestamp is specified.
             :type val_f_VrfTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VrfTimestamp: If op_VrfTimestamp is specified, this value will be compared to the value in VrfTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VrfTimestamp must be specified if op_VrfTimestamp is specified.
             :type val_c_VrfTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data collection status methods. The listed methods will be called on each data collection status returned and included in the output. Available methods are: system, cpu, memory, vlans, forwarding, environmental, inventory, arp, route, neighbor, config, access, vrf, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceID. Valid values are DeviceID, SystemInd, CPUInd, MemoryInd, VlansInd, ForwardingInd, EnvironmentalInd, InventoryInd, ARPInd, RouteInd, NeighborInd, ConfigInd, AccessInd, VrfInd, SystemTimestamp, CPUTimestamp, MemoryTimestamp, VlansTimestamp, ForwardingTimestamp, EnvironmentalTimestamp, InventoryTimestamp, ARPTimestamp, RouteTimestamp, NeighborTimestamp, ConfigTimestamp, AccessTimestamp, VrfTimestamp.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DataCollectionStatus. Valid values are DeviceID, SystemInd, CPUInd, MemoryInd, VlansInd, ForwardingInd, EnvironmentalInd, InventoryInd, ARPInd, RouteInd, NeighborInd, ConfigInd, AccessInd, VrfInd, SystemTimestamp, CPUTimestamp, MemoryTimestamp, VlansTimestamp, ForwardingTimestamp, EnvironmentalTimestamp, InventoryTimestamp, ARPTimestamp, RouteTimestamp, NeighborTimestamp, ConfigTimestamp, AccessTimestamp, VrfTimestamp. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_collection_statuses: An array of the DataCollectionStatus objects that match the specified input criteria.
             :rtype data_collection_statuses: Array of DataCollectionStatus

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)



from ..remote import RemoteModel
from infoblox_netmri.utils.utils import check_api_availability


class IfGroupRemote(RemoteModel):
    """
    Interface Group Information gathered by NetMRI.


    |  ``GroupID:`` The internal NetMRI identifier for the interface group.
    |  ``attribute type:`` number

    |  ``IfGroupID:`` The internal NetMRI identifier for the interface group.
    |  ``attribute type:`` number

    |  ``ifGroupStartTime:`` The starting effective time of this record.
    |  ``attribute type:`` datetime

    |  ``ifGroupEndTime:`` The ending effective time of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``ifGroupChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    |  ``ifGroupTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``DataSourceID:`` The internal NetMRI identifier for the collector NetMRI that collected this data record.
    |  ``attribute type:`` number


    |  ``GroupName:`` The interface group name.
    |  ``attribute type:`` string

    |  ``Criteria:`` The interface group criteria, which define the group memberships.
    |  ``attribute type:`` string

    |  ``Rank:`` The Group rank.
    |  ``attribute type:`` string

    |  ``SNMPPolling:`` The SNMP Polling indicator of the Group.
    |  ``attribute type:`` string

    |  ``FlowCollection:`` The Flow Collection indicator of the Group.
    |  ``attribute type:`` string

    |  ``PerfFrequency:`` The Group performance data gathering frequency indicator.
    |  ``attribute type:`` string

    |  ``Timestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``MemberCount:`` The number of interfaces in this interface group.
    |  ``attribute type:`` number

    """

    properties = ("GroupID",
                  "IfGroupID",
                  "ifGroupStartTime",
                  "ifGroupEndTime",
                  "ifGroupChangedCols",
                  "ifGroupTimestamp",
                  "DataSourceID",
                  "GroupName",
                  "Criteria",
                  "Rank",
                  "SNMPPolling",
                  "FlowCollection",
                  "PerfFrequency",
                  "Timestamp",
                  "MemberCount",
                  )

    @property
    @check_api_availability
    def data_source(self):
        """
        The collector NetMRI that collected this data record.
        ``attribute type:`` model
        """
        return self.broker.data_source(**{"IfGroupID": self.IfGroupID})
